@@ -275,10 +275,8 @@ def callbond_stats(value_date: str,
 
 def qlCallableBond_from_Class(call_class: CallableBondParam,
                             qlcalendar):
-    qlschedule = qlSchedule_from_Model(call_class.info,
-                                        call_class.info.settings, qlcalendar) 
+    qlschedule = qlSchedule_from_Model(call_class.info, qlcalendar) 
     structure = structure_from_qlSchedule(call_class.info,
-                                            call_class.info.settings,
                                             qlschedule)
     call_class.structure = structure
     qlcall_schedule = qlCallabilitySchedule_from_class(call_class.call_structure)
